* Code TP Analysis Dataset

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

***************************************************

insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep ballot_circle_id
duplicates drop
drop if missing(ballot_circle_id)
ren ballot_circle_id circle_id

tempfile ballotcircles
save `ballotcircles'

insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
tempfile litigation
save `litigation'

insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
keep if fyear == 2013
tempfile baselitigation
save `baselitigation'

* Baseline values
forval q = 1/4 {

	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", clear
	keep if inlist(circle_id, 900300, 900800)
	keep circle_id q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_recov_tot*
	collapse (sum) q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_recov_tot*
	gen circle_id = 900310
	tempfile overwrite
	save `overwrite'

	* Handle special case: Circle 900100 becomes 900101
	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", clear
	keep if inlist(circle_id, 900100)
	keep circle_id q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_recov_tot*
	replace circle_id = 900101
	tempfile overwrite2
	save `overwrite2'
	
	use `ballotcircles', clear
	keep circle_id
	
	merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2014_q1_crosswalk.dta", keepusing(q`q'_2013_* q`q'_2012_recov_tot* q`q'_2012_gross_dem*)
	drop if _merge == 2
	drop _merge 

	merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", keepusing(q`q'_2013_* q`q'_2012_recov_tot* q`q'_2012_gross_dem*) update
	drop if _merge == 2
	drop _merge 

	merge 1:1 circle_id using `overwrite', update
	drop _merge
	merge 1:1 circle_id using `overwrite2', update
	drop _merge
	
	rename q`q'_2012_recov_tot* pre_base_recov_tot*
	rename q`q'_2013* base*
	rename q`q'_2012_gross_dem* pre_base_gross_dem*

	foreach var in gross_dem net_dem recov_tot {
		replace base_`var'_a = round(base_`var'_a)
		replace base_`var'_c = round(base_`var'_c)
		gen base_`var'_t = base_`var'_a + base_`var'_c
	}
	
	foreach var in gross_dem net_dem recov_tot {
		foreach x in t c a {
			gen base_ln_`var'_`x' = log(base_`var'_`x')
		}
	}
	
	* Generate baseline log total recovery growth rate
	gen base_ln_recov_tot_t_growth = base_ln_recov_tot_t - log(pre_base_recov_tot_c + pre_base_recov_tot_a)
	gen base_ln_recov_tot_c_growth = base_ln_recov_tot_c - log(pre_base_recov_tot_c)
	gen base_ln_recov_tot_a_growth = base_ln_recov_tot_a - log(pre_base_recov_tot_a)
	gen base_ln_gross_dem_c_growth = base_ln_gross_dem_c - log(pre_base_gross_dem_c)
	gen base_ln_gross_dem_a_growth = base_ln_gross_dem_a - log(pre_base_gross_dem_a)
	gen base_ln_gross_dem_t_growth = base_ln_gross_dem_t - log(pre_base_gross_dem_c + pre_base_gross_dem_a)
	
	drop pre_base*
	
	if `q' == 1 {
		gen qtr = `q'
		tempfile base
		save `base'
	}
	else {
		gen qtr = `q'
		append using `base'
		save `base', replace
	}
}

* Current Values
use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To TP Randomization/2014_q1", clear

gen fyear = 2014
gen qtr = 1

tempfile data
save `data'

forval q = 2/4 {
	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To TP Randomization/2014_q`q'", clear
	
	gen fyear = 2014
	gen qtr = `q'
	
	append using `data'
	save `data', replace
}

* New analysis variables and logs
foreach x in c a t {
	gen recoveryrate_`x' = recov_tot_`x'/net_dem_`x'
	gen nonexemptrate_`x' = net_dem_`x'/gross_dem_`x'
}

foreach var in gross_dem net_dem recov_tot recoveryrate nonexemptrate {
	foreach x in t c a {
		gen ln_`var'_`x' = log(`var'_`x')
	}
}

* Merge in treatment
merge m:1 circle_id using "TP Analysis/Coded Data/Randomization Year 1"
assert _merge != 2

foreach var of varlist REV_sel DEM_sel treatment {
	replace `var' = 0 if _merge == 1
}

drop _merge
rename (REV_sel DEM_sel treatment) (REV_sel_1 DEM_sel_1 treatment_1)

* Baseline values
merge 1:1 circle_id qtr using `base', assert(match) nogen

merge m:1 circle_id using "Data/Cleaned Data/Randomization/TP Year 1 Randomization", keepusing(group_name stratum_id group_id partition_id REV_sel DEM_sel treatment) update
keep if _merge == 3
drop _merge

qui tab stratum_id, generate(stratdum)
drop stratdum1

merge 1:1 circle_id qtr using "TP Analysis/Coded Data/Implement"
drop if _merge == 2 // Excluded circles?

foreach var of varlist REV_impl DEM_impl treat_impl {
	replace `var' = 0 if _merge == 1
}

drop _merge

* Sanity check that missing values are only for litigated circles
merge 1:1 circle_id fyear qtr using `litigation'
drop if _merge == 2

assert _merge == 3 if recov_tot_t == .
drop _merge

label var treatment "Treatment"
label var REV_sel "Revenue"
label var DEM_sel "Demand"

drop  hr_id group

tempfile data
save `data'

* Year 1 HR
insheet using "Data/Raw Data/Current HR Confirmation/131028 HR Verification FY2014Q1/150109 HR Verification Q1 Inspectors.csv", comma clear
keep if inspector == 1

* Take the first inspector
keep circle_id hr_id1 ins_ac1
ren hr_id1 hr_id
ren ins_ac1 ins_ac

* Take care of randomization to Q1 crosswalk
replace circle_id = 800512 if circle_id == 800513
replace circle_id = 807101 if circle_id == 807103
replace circle_id = 807102 if circle_id == 807104

replace circle_id = 900310 if inlist(circle_id, 900300, 900800)
replace circle_id = 901210 if circle_id == 901302

replace hr_id = 999 if hr_id == .
drop if hr_id == 999 // vacant
drop if circle_id == 900310 & hr_id == 92012 // this is not the guy assigned to this circle, see the Stage II Treatment Staff file

merge 1:m circle_id using `data'
assert _merge != 2
drop if _merge == 1
drop _merge

label var circle_id "Circle ID"
label var hr_id "Balloted Inspector"
label var fyear "Fiscal Year"
label var qtr "Quarter"

forval i=1/3 {
	local x : word `i' of t c a
	local t : word `i' of Total Current Arrears
	
	label var gross_dem_`x' "Gross Demand (`t')"
	label var net_dem_`x' "Net Demand (`t')"
	label var recov_tot_`x' "Recovery (`t')"
	
	label var ln_gross_dem_`x' "Log Gross Demand (`t')"
	label var ln_net_dem_`x' "Log Net Demand (`t')"
	label var ln_recov_tot_`x' "Log Recovery (`t')"
}

order circle_id hr_id fyear qtr

save "TP Analysis/Coded Data/150525 TP Analysis Data", replace

tempfile y1_analysis_data
sa `y1_analysis_data'

* Add Y2 treatment status and save
use "TP Analysis/Coded Data/150610 Y2 Treatment Data.dta", clear
keep circle_id treatment REV_sel DEM_sel
ren (treatment REV_sel DEM_sel) (treatment_y2 REV_sel_y2 DEM_sel_y2)
merge 1:m circle_id using `y1_analysis_data'
keep if _m == 3
drop _m

save "TP Analysis/Coded Data/150525 TP Analysis Data w Y2 Treatment", replace
