* Code TP Analysis Dataset

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

***************************************************

insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep ballot_circle_id
duplicates drop
drop if missing(ballot_circle_id)
ren ballot_circle_id circle_id

tempfile ballotcircles
save `ballotcircles'

insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
tempfile litigation
save `litigation'

insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
keep if inlist(fyear, 2012, 2013)
tempfile baselitigation
save `baselitigation'

* Baseline values (2012 and 2013)
forval q = 1/4 {

	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", clear
	keep if inlist(circle_id, 900300, 900800)
	keep circle_id q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_gross_dem* q`q'_2012_net_dem* q`q'_2012_recov_tot*
	collapse (sum) q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_gross_dem* q`q'_2012_net_dem* q`q'_2012_recov_tot*
	gen circle_id = 900310
	tempfile overwrite
	save `overwrite'

	* Handle special case: Circle 900100 becomes 900101
	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", clear
	keep if inlist(circle_id, 900100)
	keep circle_id q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_gross_dem* q`q'_2012_net_dem* q`q'_2012_recov_tot*
	replace circle_id = 900101
	tempfile overwrite2
	save `overwrite2'
	
	use `ballotcircles', clear
	keep circle_id
	
	merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2014_q1_crosswalk.dta", keepusing(q`q'_2013_* q`q'_2012_*)
	drop if _merge == 2
	drop _merge 

	merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", keepusing(q`q'_2013_* q`q'_2012_*) update
	drop if _merge == 2
	drop _merge 

	merge 1:1 circle_id using `overwrite', update
	drop _merge
	merge 1:1 circle_id using `overwrite2', update
	drop _merge
	
	rename (q`q'_2013* q`q'_2012*) (y2013* y2012*)

	foreach var in gross_dem net_dem recov_tot {
		replace y2013_`var'_a = round(y2013_`var'_a)
		replace y2013_`var'_c = round(y2013_`var'_c)
		gen  y2013_`var'_t = y2013_`var'_a + y2013_`var'_c
	
		replace y2012_`var'_a = round(y2012_`var'_a)
		replace y2012_`var'_c = round(y2012_`var'_c)
		gen  y2012_`var'_t = y2012_`var'_a + y2012_`var'_c
	}
	
	foreach var in gross_dem net_dem recov_tot {
		foreach x in t c a {
			gen y2013_ln_`var'_`x' = log(y2013_`var'_`x')
			gen y2012_ln_`var'_`x' = log(y2012_`var'_`x')
		}
	}

	if `q' == 1 {
		gen qtr = `q'
		tempfile base
		save `base'
	}
	else {
		gen qtr = `q'
		append using `base'
		save `base', replace
	}
}


* 2014 Values
use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To TP Randomization/2014_q1", clear

gen fyear = 2014
gen qtr = 1

tempfile data
save `data'

forval q = 2/4 {
	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To TP Randomization/2014_q`q'", clear
	
	gen fyear = 2014
	gen qtr = `q'
	
	append using `data'
	save `data', replace
}

* New analysis variables and logs
foreach var in gross_dem net_dem recov_tot {
	foreach x in t c a {
		gen ln_`var'_`x' = log(`var'_`x')
	}
}

* Rename variables
foreach var in gross_dem net_dem recov_tot {
	foreach x in t c a {
		ren `var'_`x' y2014_`var'_`x'
		ren ln_`var'_`x' y2014_ln_`var'_`x'
	}
}

* Merge in treatment
merge m:1 circle_id using "TP Analysis/Coded Data/Randomization Year 1", keepusing(REV_sel DEM_sel treatment)
assert _merge != 2

foreach var of varlist REV_sel DEM_sel treatment {
	replace `var' = 0 if _merge == 1
	ren `var' `var'_y1
}

drop _merge
rename (REV_sel_y1 DEM_sel_y1 treatment_y1) (REV_sel_y1_1 DEM_sel_y1_1 treatment_y1_1)

* Baseline values
merge 1:1 circle_id qtr using `base', assert(match) nogen
merge m:1 circle_id using "Data/Cleaned Data/Randomization/TP Year 1 Randomization", keepusing(circle_id REV_sel DEM_sel treatment)
keep if _merge == 3 | _m == 1

*gen y2_only = _m == 1
foreach var of varlist REV_sel DEM_sel treatment {
	ren `var' `var'_y1
}
drop _merge

* Sanity check that missing values are only for litigated circles
merge 1:1 circle_id fyear qtr using `litigation'
drop if _merge == 2

assert _merge == 3 if y2014_recov_tot_t == .
drop _merge

tempfile data
save `data'

* Year 1 HR
insheet using "Data/Raw Data/Current HR Confirmation/131028 HR Verification FY2014Q1/150109 HR Verification Q1 Inspectors.csv", comma clear
keep if inspector == 1

* Take the first inspector
keep circle_id hr_id1 ins_ac1
ren hr_id1 hr_id
ren ins_ac1 ins_ac

* Take care of randomization to Q1 crosswalk
replace circle_id = 800512 if circle_id == 800513
replace circle_id = 807101 if circle_id == 807103
replace circle_id = 807102 if circle_id == 807104

replace circle_id = 900310 if inlist(circle_id, 900300, 900800)
replace circle_id = 901210 if circle_id == 901302

* Handle case where two circles merged
expand 2 if circle_id == 200301
bys circle_id: gen j = _n
replace circle_id = 200102 if circle_id == 200301 & j == 1
replace circle_id = 200300 if circle_id == 200301 & j == 2
drop j

replace hr_id = 999 if hr_id == .
drop if hr_id == 999 & !(inlist(circle_id, 203400, 905900)) // vacant
drop if circle_id == 900310 & hr_id == 92012 // this is not the guy assigned to this circle, see the Stage II Treatment Staff file

merge 1:m circle_id using `data'
assert _merge != 2
drop if _merge == 1
drop _merge

label var circle_id "Circle ID"
label var hr_id "Balloted Inspector"
label var fyear "Fiscal Year"
label var qtr "Quarter"

order circle_id fyear qtr

tempfile y1_analysis_data
sa `y1_analysis_data'

* Add 2015 values
drop fyear
merge 1:1 circle_id qtr using "TP Analysis/Coded Data/TP Y2 Analysis Data", keepusing(gross_dem* ln_gross_dem* net_dem* ln_net_dem* recov_tot* ln_recov_tot* REV_sel DEM_sel treatment partition_id group_id group_name) /// 
																			assert(1 3) /// 
																			keep(match) ///
																			nogen

* Rename variables
foreach var in gross_dem net_dem recov_tot {
	foreach x in t c a {
		ren `var'_`x' y2015_`var'_`x'
		ren ln_`var'_`x' y2015_ln_`var'_`x'
	}
}

* Rename treatment variables
foreach var in treatment REV_sel DEM_sel {
	ren `var' `var'_y2
}

* Add control variables

gen y2_only=treatment_y1==.
gen control_y1 = !treatment_y1
gen control_y2 = !treatment_y2

* Label Demand and Recovery data
forval i=1/3 {
	foreach y in 2012 2013 2014 2015 {
		local x : word `i' of t c a
		local t : word `i' of Total Current Arrears
		
		label var y`y'_gross_dem_`x' "`y' Gross Demand (`t')"
		label var y`y'_net_dem_`x' "`y' Net Demand (`t')"
		label var y`y'_recov_tot_`x' "`y' Recovery (`t')"
		
		label var y`y'_ln_gross_dem_`x' "`y' Log Gross Demand (`t')"
		label var y`y'_ln_net_dem_`x' "`y' Log Net Demand (`t')"
		label var y`y'_ln_recov_tot_`x' "`y' Log Recovery (`t')"
	}
}

* Label treatment variables
label var treatment_y1 "Y1 Treatment"
label var control_y1 "Y1 Control"
label var REV_sel_y1 "Y1 Revenue"
label var DEM_sel_y1 "Y1 Demand"
label var treatment_y2 "Y2 Treatment"
label var control_y2 "Y2 Control"
label var REV_sel_y2 "Y2 Revenue"
label var DEM_sel_y2 "Y2 Demand"

* Save
save "TP Analysis/Coded Data/Analysis Data with Lags", replace
