clear all
version 12

/*
Outline:
0. Set workspace
1. Create sample
2. Allocate circles into ONE PILOT GROUP IN LAHORE 
3. Balance checks  
4. Save files and display 
*/

**************************************************************************************************

cap cd "$PAKTAX2_RANDOMIZATION"

************************************************************************************************

*1. Create sample
use "Data for Ballot\Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL",clear 
local initial_total_obs `r(N)' 

**************************************************************************************************

*1. Create sample
*Keep only eligible circles in Lahore 
keep if partition_id == 5 // Keep only Lahore A, Lahore B

*****INSERT PILOT SEED HERE!!!*****  
merge 1:1 division_id circle_id using "Output/Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE 150.dta"

assert _merge != 2 // hard check that no circles in pilot that are not in main 
count if _merge == 3
assert `r(N)' == 10 // hard check that we only have 10 circles in pilot  
replace main_exclude = 1 if _merge == 3 
drop _merge 
drop if main_exclude == 1 // Exclude ineligible circles (including pilot) 
 
qui count
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  
summ number_circles if partition_id == 5, d
local number_circles = `r(mean)' 

assert stratum_id != . 

**************************************************************************************************
*2. Allocate circles in main sample to groups 

sort stratum_id circle_id 
**Select seed for main ballot 
noisily display "Enter the number chosen by ballot: " _request(SEEDINPUT)
display "$SEEDINPUT"
set seed $SEEDINPUT
set sortseed $SEEDINPUT

sort stratum_id circle_id 
g rand2 = runiform()	
by stratum_id: egen rank2 = rank(rand2), unique // rank2 within strata 
by stratum_id: egen count2 = count(rand2)

**Allocate circles into groups by stratified randomization. 
**First figure out the number of groups we need. 
**Ideal group size is 10 circles.  We get as close as possible to this.  

*Preparing for allocation
local num_groups = floor(`number_circles'/10) 
local test1 = abs(`number_circles'/`num_groups' - 10)
local test2 = abs(`number_circles'/(`num_groups' + 1) - 10) 

if `test1' > `test2' { // if adding a group brings average closer to 10, then add a group  
	local num_groups = `num_groups' + 1 
}	

g group = .  
levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	count if division_id == `d'
	local num_circles = `r(N)'
	local per_group = floor(`num_circles'/`num_groups')
	local per_bin = floor(`per_group'/3) 

	forvalues i = 1(1)`num_groups'{
		#delimit ; 
		replace group = `i' if rank2 >= `per_bin' *(`i'-1) + 1 
			& rank2 <= `per_bin' *`i' & division_id == `d' ; 
		#delimit cr 
	}
}

**Now deal with the residual circles. 
**Randomly rank strata
sort stratum_id circle_id
by stratum_id: g temprand1 = runiform() if _n == 1 
egen strata_rank = rank(temprand1), unique  
by stratum_id: egen temp = max(strata_rank) 
replace strata_rank = temp 
drop temp 

**Randomly rank group
sort group circle_id
by group: g temprand2 = runiform() if _n == 1 & group != .
egen group_rank = rank(temprand2), unique  
by group: egen temp = max(group_rank) 
replace group_rank = temp 
drop temp 

summ strata_rank if partition_id == 5, d
local strata_max = `r(max)' 
local grouprank_counter = 1 

forvalues s = 1(1)`strata_max'{
	count if group == . & strata_rank == `s' // number of remaining circles in randomly selected strata
	local remaining_circles = `r(N)' 
	
	while `remaining_circles' > 0 {
		summ rank2 if strata_rank == `s' & group == . , d
		local min_rank = `r(min)' 
		summ group if group_rank == `grouprank_counter', d
		local group = `r(min)'  
		replace group = `group' if rank2 == `min_rank' & strata_rank == `s' 

		local grouprank_counter = `grouprank_counter' + 1 
		if `grouprank_counter' > `num_groups' {
			local grouprank_counter 1		
		}	
		
		count if group == . & strata_rank == `s' // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	}
	count if group == . & strata_rank == `s'
	assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
}
count if group == . 
assert `r(N)' == 0 // make sure no circles are without a group allocation
replace group = group + 1 // adjust for pilot group that came in Lahore before 


**************************************************************************************************
*3. Save data, outsheet groups, and display groups of circles
save "Output/Year 1/130726 Lahore Transfers Main Randomization $SEEDINPUT", replace
sort group division_name circle_id
