clear all
version 12

**************************************************************************************************

cap cd "$PAKTAX2_RANDOMIZATION"

************************************************************************************************

*1. Open sample from first ballot - Pilot Seed == 51135, Main Seed == 606

use "Output/Year 1/130803 Other Divisions Transfers Main Randomization 606.dta", clear

************************************************************************************************

*2. Select groups from each partition for treatment 
sort group circle_id 
**Select seed for treatment assignment ballot: 
noisily display "Enter the number chosen by ballot: " _request(SEEDINPUT)
display "$SEEDINPUT"
set seed $SEEDINPUT
set sortseed $SEEDINPUT

sort partition_id group circle_id
by partition_id group: g rand7 = runiform() if _n == 1 
by partition_id: egen rank7 = rank(rand7), unique // rank7 groups within a partition  
by partition_id group: egen temp = max(rank7)
replace rank7 = temp 
drop temp

**Select groups for treatment.  
g treatment = ""
replace treatment = "CHOICE GROUP 1" if rank7 == 1 
replace treatment = "CHOICE GROUP 2" if rank7 == 2
replace treatment = "" if rank7 == 2 & partition_id == 10 // Sarghoda should only have 1 treatment group 
g lottery_group = treatment 

**Select which groups will be ranked by recovery and which groups by demand
sort partition_id treatment circle_id
by partition_id treatment: g rand8 = runiform() if _n == 1 & treatment != "" 
by partition_id: egen rank8 = rank(rand8), unique // rank8 treatment groups within a partition 
by partition_id treatment: egen temp = max(rank8)
replace rank8 = temp
drop temp

g ranking_method = ""
replace ranking_method = "RECOVERY" if rank8 == 1 // This will ensure Sarghoda gets ranked by recovery 
replace ranking_method = "DEMAND" if rank8 == 2

************************************************************************************************

*3. Balance Checks
cap drop ln*
for any gross_dem_c gross_dem_t net_dem_c net_dem_t recov_tot_c recov_tot_t recov_tot_t_12q3: g ln_X = ln(X) 
g ln_change_recovery = ln(recov_tot_t/recov_tot_t_12q3) 

desc ln*, varlist
local sumstatvars "`r(varlist)'"
local number_variables `r(N)' 

forvalues i = 0(1)14{
	g col`i' = . // column placeholders
}

*Calculate summary statistics
local variable_number = 1

levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	foreach var in `sumstatvars'{
		replace col0 = `i' if _n == `variable_number' // partition_id 
				
		summ `var' if treatment != "" & partition_id == `i', d
		replace col1 = `r(mean)' if _n == `variable_number'
		replace col2 = `r(N)' if _n == `variable_number' 
	
		*T-Tests
		g temp = 1 if treatment != "" & partition_id == `i'
		replace temp = 0 if treatment == "" & partition_id == `i'
		ttest `var', by(temp) 
		replace col3 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
		replace col4 = `r(p)' if _n == `variable_number' 
		drop temp

		summ `var' if treatment == "CHOICE GROUP 1" & partition_id == `i', d
		replace col5 = `r(mean)' if _n == `variable_number'
		replace col6 = `r(N)' if _n == `variable_number' 
	
		*T-Tests
		g temp = 1 if treatment == "CHOICE GROUP 1" & partition_id == `i'
		replace temp = 0 if treatment == "" & partition_id == `i'
		ttest `var', by(temp) 
		replace col7 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
		replace col8 = `r(p)' if _n == `variable_number' 
		drop temp

		summ `var' if treatment == "CHOICE GROUP 2" & partition_id == `i', d
		cap replace col9 = `r(mean)' if _n == `variable_number'
		cap replace col10 = `r(N)' if _n == `variable_number' 
	
		*T-Tests
		g temp = 1 if treatment == "CHOICE GROUP 2" & partition_id == `i'
		replace temp = 0 if treatment == "" & partition_id == `i'
		cap ttest `var', by(temp) 
		cap replace col11 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
		cap replace col12 = `r(p)' if _n == `variable_number' 
		drop temp

		summ `var' if treatment == "" & partition_id == `i', d 
		replace col13 = `r(mean)' if _n == `variable_number'
		replace col14 = `r(N)' if _n == `variable_number' 
		
		forvalues j = 1(1)14{
			replace col`j' = round(col`j', 0.001) if _n == `variable_number' 
		}
		local variable_number = `variable_number' + 1
	}
	local variable_number = `variable_number' + 2	
}

************************************************************************************************

*4. Save data & and display treatment groups
sort group division_name circle_id
save "Output/Year 1/130829 Other Divisions Assign Treatment Transfers Randomization Output $SEEDINPUT", replace
