clear all
version 12

**************************************************************************************************

cap cd "$PAKTAX2_RANDOMIZATION"

************************************************************************************************

*1. Create sample
use "Data for Ballot\Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL - Non-Lahore",clear 
local initial_total_obs `r(N)' 

**************************************************************************************************

*1. Create sample
*Keep only eligible circles in other divisions
drop if partition_id == 5 // Drop Lahore A, Lahore B as this has already been balloted
drop if inlist(partition_id, 2, 6, 9) // Drop DG Khan, Lahore C, and Sahiwal 

*****INSERT PILOT SEED HERE!!!*****  
merge 1:1 division_id circle_id using "Output/Year 1/130803 Multan PILOT Transfers Randomization Output MERGE 51135.dta"

assert _merge != 2 // hard check that no circles in pilot that are not in main 
count if _merge == 3
assert `r(N)' == 10 // hard check that we only have 10 circles in pilot  
replace main_exclude = 1 if _merge == 3 
drop _merge

drop if main_exclude == 1 // Exclude ineligible circles (including pilot) 
 
qui count
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  

assert stratum_id != .  

**************************************************************************************************

*2. Allocate circles in main sample to groups 
sort stratum_id circle_id 
**Select seed for main ballot 
noisily display "Enter the number chosen by ballot: " _request(SEEDINPUT)
display "$SEEDINPUT"
set seed $SEEDINPUT
set sortseed $SEEDINPUT

sort stratum_id circle_id 
g rand6 = runiform()	
by stratum_id: egen rank6 = rank(rand6), unique // rank6 within strata 
by stratum_id: egen count6 = count(rand6)

**Allocate circles into groups by stratified randomization. 
**First figure out the number of groups we need. 
**Ideal group size is 10 circles.  We get as close as possible to this.  

*Preparing for allocation 
g num_groups = floor(number_circles/10) 
g test1 = abs(number_circles/num_groups - 10)
g test2 = abs(number_circles/(num_groups + 1) - 10) 

levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ test1 if partition_id == `i', d
	local test1 `r(mean)'
	summ test2 if partition_id == `i', d
	local test2 `r(mean)'
	
	if (`test1' > `test2') { // if adding a group brings average closer to 10, then add a group  
		replace num_groups = num_groups + 1 if partition_id == `i'
	}
}

g group = .  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	count if partition_id == `i'
	local num_circles = `r(N)'
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	local per_group = floor(`num_circles'/`num_groups')
	local per_bin = floor(`per_group'/3) 

	forvalues g = 1(1)`num_groups'{
		#delimit ; 
		replace group = `g' if rank6 >= `per_bin' *(`g'-1) + 1 
			& rank6 <= `per_bin' *`g' & partition_id == `i' ; 
		#delimit cr 
	}
}

**Now deal with the residual circles.  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	**Randomly rank strata
	sort stratum_id circle_id
	by stratum_id: g temprand1 = runiform() if _n == 1 & partition_id == `i'
	egen strata_rank = rank(temprand1), unique 
	by stratum_id: egen temp = max(strata_rank) 
	replace strata_rank = temp 
	drop temp 

	**Randomly rank group
	sort partition_id group circle_id
	by partition_id group: g temprand2 = runiform() if _n == 1 & group != . & partition_id == `i'
	egen group_rank = rank(temprand2), unique   
	by partition_id group: egen temp = max(group_rank) 
	replace group_rank = temp 
	drop temp 
	
	summ strata_rank if partition_id == `i', d
	local strata_max = `r(max)' 
	local grouprank_counter = 1 

	forvalues s = 1(1)`strata_max'{
		count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	
		while `remaining_circles' > 0 {
			summ rank6 if strata_rank == `s' & group == . & partition_id == `i', d
			local min_rank = `r(min)' 
			summ group if group_rank == `grouprank_counter' & partition_id == `i', d
			local group = `r(min)'  
			replace group = `group' if rank6 == `min_rank' & strata_rank == `s' & partition_id == `i'

			local grouprank_counter = `grouprank_counter' + 1 
			if `grouprank_counter' > `num_groups' {
				local grouprank_counter = 1 		
			}	
		
			count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
			local remaining_circles = `r(N)' 
		}
		count if group == . & strata_rank == `s' & partition_id == `i' 
		assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
	}

	drop temprand* strata_rank group_rank
}

count if group == . 
assert `r(N)' == 0 // make sure no circles are without a group allocation
replace group = group + 1 if partition_id == 7 // adjust for pilot group that came in Multan before 

**************************************************************************************************

*3. Save data, outsheet groups, and display groups of circles
save "Output/Year 1/130803 Other Divisions Transfers Main Randomization $SEEDINPUT", replace
