function pref_ranks = find_pref_ranks(ins, prefs, full_knowledge)
    % ins refers to the index of the target inspector
    % prefs is the list of preferences for the given group
    [num_ins, num_circles] = size(prefs);
    
    if full_knowledge == 0 % Inspector assumes everyone shares his preferences
        pref_ranks = (1:num_ins);
    
    else
        % Preferences of target inspector removed from preference list
        ins_prefs = prefs(ins,:);
        prefs(ins,:) = [];
        
        % If inspector assumes others' preferences are random
        if full_knowledge == 2
            for i = 1:(num_ins-1) % For all other inspectors
                row = prefs(i,:);
                prefs(i,:) = row(randperm(length(row))); % Shuffle row
            end
        end
        
        % Element at index i is the "preference rank" if inspector achieves
        % rank i.
        pref_ranks = zeros(num_ins, 1);

        % Helper variables
        next_available = ones(num_ins-1, 1); % rank of next available circle
        next_available_confirmed = zeros(num_ins-1, 1);
        ins_next_available = 1;

        % If inspector rank is one, pref rank is obviously also 1
        pref_ranks(1) = 1;

        % For each round of transfers
        for r = 1:(num_ins-1)

            % Find posting circle for inspector ranked r
            posting_circle = prefs(r, next_available(r));

            % Reset helper variables
            next_available_confirmed(:) = 0;
            ins_next_available_confirmed = 0;

            % Remove newly posted circle from preference rankings
            prefs(prefs == posting_circle) = NaN;
            ins_prefs(ins_prefs == posting_circle) = NaN;

            % For the num of circles in the group
            for k = 1:num_circles

                % Find next available transfer for each inspector
                next_available(~next_available_confirmed & ~isnan(prefs(:, k))) = k;
                next_available_confirmed(~isnan(prefs(:, k))) = 1;

                % Find next available transfer for the "target" inspector
                if ~ins_next_available_confirmed && ~isnan(ins_prefs(k))
                    ins_next_available = k;
                    ins_next_available_confirmed = 1;
                end
            end

            % Add target inspectors posting to list of preference ranks
            pref_ranks(r+1) = ins_next_available;
        end       
    end
end