/*
	Balance table using rand data, Y1 and Y2
*/


********************************************************************************
* Initial Setup
********************************************************************************

clear all
set more off
pr drop _all
cap log close
set mem 300m
set trace off
set maxvar 32000
set matsize 10500
local num 2000
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Declare input files here
local y2_analysis_file = 			"Coded Data/TP Y2 Analysis Data"
local y1_analysis_file = 			"Coded Data/150525 TP Analysis Data"
local python_file = 				"Do Files/Paper/clean_balance_table.py"

* Declare output files here
local output_file = 				"balance_table_nofe_rand_pooled"

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval 
program define add_pval, eclass // Name of the command
syntax,  results(string) pval1(real) indvar1(string)  // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,1,.) // Opens a space for pvalue
matrix colnames pval="`indvar1'"

matrix pval[1,1]=`pval1' // Defines where the value comes from

estadd matrix pval pval // Stores the matrix

end

********************************************************************************
* Prepare datasets using the data that was in place before
********************************************************************************

*YEAR 1 data

use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
keep if qtr==4
tempfile base1
save `base1'

*YEAR 1

use "../Data\Randomization\Output\Year 1/130803 Lahore Assign Treatment Transfers Randomization Output 2100", clear
append using "../Data\Randomization\Output\Year 1/130829 Other Divisions Assign Treatment Transfers Randomization Output 17921"

merge 1:1 circle_id using `base1', keep(1 3) keepusing(base* pre*)

drop treatment
gen treatment = ranking_method != ""
gen REV_sel = ranking_method == "RECOVERY"
gen DEM_sel = ranking_method == "DEMAND"
replace group = 3 if partition_id == 10 & treatment == 1
egen group_id = group(partition_id group)
decode partition_id, generate(partition)
gen temp = " "
egen group_name = concat(partition temp group)
drop temp partition
drop group

tempfile y1_analysis_file
save `y1_analysis_file'

*YEAR 2

u "../Data\Randomization\Output\Year 1/130726 Lahore PILOT Transfers Randomization Output 150", clear
keep if treatment == "PILOT GROUP"
gen circle_type = "Control"
drop treatment
gen new = 0
gen continuing = 0
tempfile lhr_pilot
sa `lhr_pilot'

* Load 10 Multan Pilot group from Year 1
u "../Data\Randomization\Output\Year 1/130803 Multan PILOT Transfers Randomization Output 51135", clear
keep if treatment == "PILOT GROUP"
gen circle_type = "Control"
drop treatment
gen new = 0
gen continuing = 0
tempfile multan_pilot
sa `multan_pilot'

u "../Data\Randomization\Output\Year 2/140830 Control Groups Year 2 Randomization 391", clear
drop if treatment==1
gen circle_type = "Control"
drop treatment
gen new = 0
gen continuing = 0
tempfile control
sa `control'

* Adding 72 Non-Continuing circles to control
u "../Data\Randomization\Output\Year 2/140805 Treated Groups Year 2 Randomization 500060"
drop if treatment==1
gen circle_type = "Control"
drop treatment
gen new = 0
gen continuing = 0
tempfile non_cont
sa `non_cont'

* Add treatment circles to list
u "../Data\Randomization\Output\Year 2/140830 Control Groups Year 2 Randomization 391", clear
append using "../Data\Randomization\Output\Year 2/140805 Treated Groups Year 2 Randomization 500060"
keep if treatment==1
replace details_treatment="New" if details_treatment=="control in year 1 & treatment in year 2" | details_treatment=="excl. in year 1 & treatment in year 2"
replace details_treatment="Continuing" if details_treatment=="dynamic incentives in year 1 & year 2" 
gen circle_type = "Treatment"
drop treatment
gen new = details_treatment == "New"
gen continuing = details_treatment == "Continuing"
drop details_treatment
ren ranking_method scheme

append using `lhr_pilot'
append using `multan_pilot'
append using `control'
append using `non_cont'

drop q3_2013_recov_tot_c q3_2013_recov_tot_a q3_2013_recov_tot_t recov_tot_t_12q3 // so that you can insert data for everyone

merge 1:1 circle_id using `base1', keep(1 3) keepusing(base* pre*) nogen

replace division_name = "LAHORE" if inlist(division_name, "LAHORE A", "LAHORE B")
gen temp = " "
egen group_name = concat(division_name temp group)
drop temp
replace group_name = "SARGODHA 3" if group_name=="SARGODHA 1" & circle_type=="Treatment"
tab group_name

gen DEM_sel = scheme == "DEMAND"
gen REV_sel = scheme == "RECOVERY"
drop scheme
tab stratum_id, generate(stratdum)
drop stratum_id

gen treatment = DEM_sel + REV_sel
ren new new_sel
ren continuing cont_sel

tempfile y2_analysis_file
save `y2_analysis_file'


quietly {

********************************************************************************
* Load data
********************************************************************************

********************************************************************************
* Y1 data
********************************************************************************

use "`y1_analysis_file'", clear

gen base_ln_nonexemptrate_t = base_ln_net_dem_t - base_ln_gross_dem_t
gen base_ln_recoveryrate_t = base_ln_recov_tot_t - base_ln_net_dem_t

ren (base_ln_recov_tot_t base_ln_nonexemptrate_t base_ln_recoveryrate_t base_ln_recov_tot_t_growth) ///
	(recov exempt recovrate growth)

keep circle_id treatment* REV_sel* DEM_sel* recov exempt recovrate growth strat* 

gen control = treatment == 0

tempfile y1_analysis
sa `y1_analysis'

********************************************************************************
* Y2 data
********************************************************************************

use "`y2_analysis_file'", clear
drop ln_*
cap drop q1* q2* q4*

*Identify variables we need

gen base_ln_nonexemptrate_t = base_ln_net_dem_t - base_ln_gross_dem_t
gen base_ln_recoveryrate_t = base_ln_recov_tot_t - base_ln_net_dem_t

ren (base_ln_recov_tot_t base_ln_nonexemptrate_t base_ln_recoveryrate_t base_ln_recov_tot_t_growth) ///
	(recov exempt recovrate growth)

keep circle_id treatment* REV_sel* DEM_sel* recov exempt recovrate growth stratdum*

gen control = treatment == 0

rename treatment treatment_y2
merge 1:1 circle_id using `y1_analysis', keepusing(treatment) keep(3)
keep if treatment==0
drop treatment
rename treatment_y2 treatment

tempfile y2_analysis
sa `y2_analysis'

********************************************************************************
* Pooled data
********************************************************************************

use `y1_analysis', clear
gen y1=1
append using `y2_analysis'
replace y1=0 if mi(y1)
tempfile pooled_analysis
save `pooled_analysis'

********************************************************************************
* Load randomized data
********************************************************************************

use "Coded Data/RI/rand_code_iter.dta", clear
tempfile rand_data
save `rand_data'
preserve
keep circle_id *y1*
tempfile y1_rand_data
save `y1_rand_data'
restore
preserve
keep circle_id *y2*
tempfile y2_rand_data
save `y2_rand_data'
restore
use `y1_rand_data', clear
gen y1=1
append using `y2_rand_data'
replace y1=0 if mi(y1)
tempfile pooled_rand_data
save `pooled_rand_data'

foreach y in "y1" "y2"  {
use ``y'_analysis', clear
merge 1:1 circle_id using ``y'_rand_data', assert(2 3) keep(3)  nogen
save ``y'_analysis', replace
}
use `pooled_analysis', clear
merge 1:1 circle_id y1 using `pooled_rand_data', nogen assert(2 3) keep(3)
save `pooled_analysis', replace

********************************************************************************
* Run regressions, rand files
********************************************************************************

* Matrix with betas

	foreach y in 1 2 3 {
	foreach group in treat rev dem {
	matrix beta_`group'_y`y'= J(`num',4,.)
	matrix list beta_`group'_y`y'
	}
	}
		
	foreach y in 1 2 3 {	
		
	if `y'!=3  {

	forvalues v=1/4 { 
	local var: word `v' of recov exempt recovrate growth 

	forvalues m=1/`num' {

		use `y`y'_analysis', clear
		cap drop treatment_1
		drop treatment DEM_sel REV_sel
		rename (treatment_y`y'_`m' DEM_sel_y`y'_`m' REV_sel_y`y'_`m') (treatment DEM_sel REV_sel)
		drop treatment_* DEM_sel_* REV_sel_*
		
			* Control means
			gen t = 1
			summ `var' if treatment == 0
			gen m = `r(mean)'	
			eststo `var'_conty`y' : 		qui reg m t, nocons
			drop t m

			* ANY treatment regression
			ren treatment t
			reg `var' t /*stratdum**/, robust
			matrix beta_treat_y`y'[`m',`v']=_b[t]
			ren t treatment
			
			* REVENUE treatment regression
			ren REV_sel t
			reg `var' t DEM_sel  /*stratdum**/, robust
			matrix beta_rev_y`y'[`m',`v']=_b[t]
			ren t REV_sel
			
			* DEMAND treatment regression
			ren DEM_sel t
			reg `var' REV_sel t  /*stratdum**/, robust
			matrix beta_dem_y`y'[`m',`v']=_b[t]
			ren t DEM_sel
			
	}
	}
		
	}

	else  {

	forvalues v=1/4 { 
	local var: word `v' of recov exempt recovrate growth 
	
	forvalues m=1/`num' {

		use `pooled_analysis', clear
		cap drop treatment_1
		drop treatment DEM_sel REV_sel
		foreach scheme in treatment DEM_sel REV_sel {
		gen `scheme'_`m'=.
		replace `scheme'_`m'=`scheme'_y1_`m' if y1==1
		replace `scheme'_`m'=`scheme'_y2_`m' if y1==0
		assert !mi(treatment_`m')
		}
		rename (treatment_`m' DEM_sel_`m' REV_sel_`m') (treatment DEM_sel REV_sel)
		drop treatment_* DEM_sel_* REV_sel_*
		
			* Control means
			gen t = 1
			summ `var' if treatment == 0
			gen m = `r(mean)'	
			eststo `var'_conty`y' : 		qui reg m t y1, nocons
			drop t m
			
			* ANY treatment regression
			ren treatment t
			reg `var' t y1 /*stratdum**/, robust
			matrix beta_treat_y`y'[`m',`v']=_b[t]
			ren t treatment
			
			* REVENUE treatment regression
			ren REV_sel t
			reg `var' t DEM_sel  /*stratdum**/, robust
			matrix beta_rev_y`y'[`m',`v']=_b[t]
			ren t REV_sel
			
			* DEMAND treatment regression
			ren DEM_sel t
			reg `var' REV_sel t  /*stratdum**/, robust
			matrix beta_dem_y`y'[`m',`v']=_b[t]
			ren t DEM_sel
			
	}
	}
	
	}

* Var-Cov Matrix

		foreach group in treat rev dem {
		matrix list beta_`group'_y`y'
		svmat beta_`group'_y`y'
		keep beta_`group'_y`y'* 
		drop if _n>`num'
		tempfile beta_`group'_y`y'
		save `beta_`group'_y`y''
		corr beta_`group'_y`y'* , cov
		matrix varcov_`group'y`y'=J(4,4,.) 
		matrix  varcov_`group'y`y'=r(C) // Defines where the value comes from
		matrix list  varcov_`group'y`y'
		}
		
		}
		
		foreach group in treat rev dem {
		forvalues y=1/3 {
		matrix stats_`group'_y`y'= J(`num',1,.)
		forvalues m=1/`num' {
		use `beta_`group'_y`y'', clear
		keep if _n==`m'
		mkmat beta_`group'_y`y'1 beta_`group'_y`y'2 beta_`group'_y`y'3 beta_`group'_y`y'4, matrix(beta_`group'_y`y'_t)
		matrix beta_`group'_y`y'=beta_`group'_y`y'_t'
		matrix stats_`group'_y`y'[`m',1]=beta_`group'_y`y'_t* varcov_`group'y`y'*beta_`group'_y`y'
		svmat stats_`group'_y`y'
		tempfile stats_`group'_y`y'
		save `stats_`group'_y`y''
		}
		}
		}

********************************************************************************
* Run regressions
********************************************************************************

forvalues z=1/3 {
local group: word `z' of  treat rev dem
forvalues y=1/3 {
matrix beta_0_`group'y`y'=J(4,1,.) 
}
}

/*
Some important points about the regressions below:

- For formatting reasons, we run a regression of CONSTANT control mean on a CONSTANT equal to 1.
- We always rename the primary regressor to "t", to ensure that the regressors line up in our table
- To run a joint test of coefficients across multiple models, we have to rerun each regression
	without "robust" specified, then use "suest" with the "robust" option to get the correct SEs.
- We run a regression at the bottom of the for loop whose values will never be displayed. This is
	simply to make it easier to add a panel of stats at the bottom of the table.

*/

foreach y in 1 2 3 {

	if `y'!=3 {
	
	use `y`y'_analysis', clear
	cap drop treatment_1
	
	forvalues k=1/4 {
	local var: word `k' of recov exempt recovrate growth
	
		* Control means
		gen t = 1
		summ `var' if treatment == 0
		gen m = `r(mean)'	
		eststo `var'_conty`y' : 		qui reg m t, nocons
		drop t m
		
		* ANY treatment regression
		ren treatment t
		eststo `var'_treaty`y' :		qui reg `var' t /*stratdum**/, robust
		local real_beta = _b[t]
		matrix list beta_`group'_y`y'
		matrix beta_0_treaty`y'[`k',1]=`real_beta'
		preserve
		use `beta_treat_y`y'', clear
		keep beta_treat_y`y'`k'
		keep if abs(beta)> abs(`real_beta')
		if _N==0{
			local pval= 0.001
			}
		else {
		local pval = _N / `num'
		}
		display `pval'
		restore
		add_pval, results(`var'_treaty`y' ) pval1(`pval') indvar1(t) 
		eststo `var'_treaty`y' 
		eststo `var'_stat_treaty`y' :	qui reg `var' t  /*stratdum**/
		ren t treatment
		
		* REVENUE treatment regression
		ren REV_sel t
		eststo `var'_revy`y' :			qui reg `var' t DEM_sel  /*stratdum**/, robust
		local real_beta = _b[t]
		matrix beta_0_revy`y'[`k',1]=`real_beta'
		preserve
		use `beta_rev_y`y'', clear
		keep beta_rev_y`y'`k'
		keep if abs(beta)> abs(`real_beta')
		if _N==0{
			local pval= 0.001
			}
		else {
		local pval = _N / `num'
		}
		display `pval'
		restore
		add_pval, results(`var'_revy`y' ) pval1(`pval') indvar1(t) 
		eststo `var'_revy`y' 
		eststo `var'_stat_revy`y' :		qui reg `var' t DEM_sel  /*stratdum**/
		ren t REV_sel

		* DEMAND treatment regression
		ren DEM_sel t
		eststo `var'_demy`y' :			qui reg `var' REV_sel t  /*stratdum**/, robust
		local real_beta = _b[t]
		matrix beta_0_demy`y'[`k',1]=`real_beta'
		preserve
		use `beta_dem_y`y'', clear
		keep beta_dem_y`y'`k'
		keep if abs(beta)> abs(`real_beta')
		if _N==0{
			local pval= 0.001
			}
		else {
		local pval = _N /`num'
		}
		display `pval'
		restore
		add_pval, results(`var'_demy`y' ) pval1(`pval') indvar1(t) 
		eststo `var'_demy`y' 
		eststo `var'_stat_demy`y' :		qui reg `var' REV_sel t  /*stratdum**/
		ren t DEM_sel
	}
	
	* Add joint-test

	forvalues z=1/3 {
	local group: word `z' of  treat rev dem
	
	matrix beta_0_`group'y`y'_t=beta_0_`group'y`y''
	matrix temp=J(1,1,.)
	matrix temp= beta_0_`group'y`y'_t*varcov_`group'y`y'*beta_0_`group'y`y'
	matrix list temp
	local temp=temp[1,1]
	display `temp'
	
	eststo stat_`group'y`y' : reg DEM_sel REV_sel // dummy regression, will not show up in table!
	
	preserve	
	use `stats_`group'_y`y'', clear
	keep if stats> `temp'
	display `temp'
	if _N==0{
		local pval= 0.001
		}
	else {
	local pval = _N / `num'
	}
	display `pval'
	restore
	
	estadd scalar jointp = `pval'
	eststo stat_`group'y`y'

	}	
}

	else {
	
	use `pooled_analysis', clear
	cap drop treatment_1	
	forvalues k=1/4 {
	local var: word `k' of recov exempt recovrate growth
	
		* Control means
		gen t = 1
		summ `var' if treatment == 0
		gen m = `r(mean)'	
		eststo `var'_conty`y' : 		qui reg m t y1, nocons
		drop t m
		
		* ANY treatment regression
		ren treatment t
		eststo `var'_treaty`y' :		qui reg `var' y1 t /*stratdum**/, robust
		local real_beta = _b[t]
		matrix list beta_`group'_y`y'
		matrix beta_0_treaty`y'[`k',1]=`real_beta'
		preserve
		use `beta_treat_y`y'', clear
		keep beta_treat_y`y'`k'
		keep if abs(beta)> abs(`real_beta')
		if _N==0{
			local pval= 0.001
			}
		else {
		local pval = _N / `num'
		}
		display `pval'
		restore
		add_pval, results(`var'_treaty`y' ) pval1(`pval') indvar1(t) 
		eststo `var'_treaty`y' 
		eststo `var'_stat_treaty`y' :	qui reg `var' t  /*stratdum**/
		ren t treatment
		
		* REVENUE treatment regression
		ren REV_sel t
		eststo `var'_revy`y' :			qui reg `var' y1 t DEM_sel  /*stratdum**/, robust
		local real_beta = _b[t]
		matrix beta_0_revy`y'[`k',1]=`real_beta'
		preserve
		use `beta_rev_y`y'', clear
		keep beta_rev_y`y'`k'
		keep if abs(beta)> abs(`real_beta')
		if _N==0{
			local pval= 0.001
			}
		else {
		local pval = _N / `num'
		}
		display `pval'
		restore
		add_pval, results(`var'_revy`y' ) pval1(`pval') indvar1(t) 
		eststo `var'_revy`y' 
		eststo `var'_stat_revy`y' :		qui reg `var' t y1 DEM_sel  /*stratdum**/
		ren t REV_sel

		* DEMAND treatment regression
		ren DEM_sel t
		eststo `var'_demy`y' :			qui reg `var' y1 REV_sel t  /*stratdum**/, robust
		local real_beta = _b[t]
		matrix beta_0_demy`y'[`k',1]=`real_beta'
		preserve
		use `beta_dem_y`y'', clear
		keep beta_dem_y`y'`k'
		keep if abs(beta)> abs(`real_beta')
		if _N==0{
			local pval= 0.001
			}
		else {
		local pval = _N /`num'
		}
		display `pval'
		restore
		add_pval, results(`var'_demy`y' ) pval1(`pval') indvar1(t) 
		eststo `var'_demy`y' 
		eststo `var'_stat_demy`y' :		qui reg `var' y1 REV_sel t  /*stratdum**/
		ren t DEM_sel
	}
	
	* Add joint-test

	forvalues z=1/3 {
	local group: word `z' of  treat rev dem
	
	matrix beta_0_`group'y`y'_t=beta_0_`group'y`y''
	matrix temp=J(1,1,.)
	matrix temp= beta_0_`group'y`y'_t*varcov_`group'y`y'*beta_0_`group'y`y'
	matrix list temp
	local temp=temp[1,1]
	display `temp'
	
	eststo stat_`group'y`y' : reg DEM_sel REV_sel // dummy regression, will not show up in table!
	
	preserve	
	use `stats_`group'_y`y'', clear
	keep if stats> `temp'
	display `temp'
	if _N==0{
		local pval= 0.001
		}
	else {
	local pval = _N / `num'
	}
	display `pval'
	restore
	
	estadd scalar jointp = `pval'
	eststo stat_`group'y`y'

	}	
}
}


********************************************************************************
* Draw table
********************************************************************************

local file "`output_file'"

# delimit ;
	esttab recov_conty1 recov_treaty1 recov_revy1 recov_demy1 recov_conty2 recov_treaty2 recov_revy2 recov_demy2 recov_conty3 recov_treaty3 recov_revy3 recov_demy3
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",
		
		keep(t)
		
		coeflabels(t "Log Recovery")
		collabels(none)		
		cells(b(fmt(%12.3f))
		se(fmt(%12.3f) par)
		pval(fmt(%12.3f) par([ ]))
		)
		
		starlevels(* .10 ** .05 *** .01) // significance levels
		
		mtitles("Control" "Treatment" "Revenue" "Demand" "Control" "Treatment" "Revenue" "Demand" "Control" "Treatment" "Revenue" "Demand") // Column headings
		
		mgroups(
			"Year 1 Randomization" "Year 2 Randomization"  "Pooled",
			pattern(1 0 0 0 1 0 0 0 1 0 0 0)
			prefix(\multicolumn{@span}{c}{)
			suffix(}) span erepeat(\cmidrule(lr){@span})
		)
		
		noobs
		nonumbers
		label // Use Variable Labels
		booktabs // a nicer version of tables
		substitute("<" "$<$")
		fragment
		replace
		;

# delimit cr

# delimit ;
	esttab recovrate_conty1 recovrate_treaty1 recovrate_revy1 recovrate_demy1 recovrate_conty2 recovrate_treaty2 recovrate_revy2 recovrate_demy2 recovrate_conty3 recovrate_treaty3 recovrate_revy3 recovrate_demy3
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",
		
		keep(t)
		
		coeflabels(t "Log Recovery Rate")
		collabels(none)				
		cells(b(fmt(%12.3f))
		se(fmt(%12.3f) par)
		pval(fmt(%12.3f) par([ ]))
		)
		
		starlevels(* .10 ** .05 *** .01) // significance levels
		
		nolines
		noobs
		nonumbers
		nomtitles
		label // Use Variable Labels
		booktabs // a nicer version of tables
		fragment
		append
		;

# delimit cr

# delimit ;
	esttab exempt_conty1 exempt_treaty1 exempt_revy1 exempt_demy1 exempt_conty2 exempt_treaty2 exempt_revy2 exempt_demy2 exempt_conty3 exempt_treaty3 exempt_revy3 exempt_demy3
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",
		
		keep(t)
		
		coeflabels(t "Log Non-Exemption Rate")
		collabels(none)		
		cells(b(fmt(%12.3f))
		se(fmt(%12.3f) par)
		pval(fmt(%12.3f) par([ ]))
		)
		
		starlevels(* .10 ** .05 *** .01) // significance levels
		
		nolines
		noobs
		nonumbers
		nomtitles
		label // Use Variable Labels
		booktabs // a nicer version of tables
		fragment
		append
		;

# delimit cr

# delimit ;
	esttab growth_conty1 growth_treaty1 growth_revy1 growth_demy1 growth_conty2 growth_treaty2 growth_revy2 growth_demy2 growth_conty3 growth_treaty3 growth_revy3 growth_demy3
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",
		
		keep(t)
		
		coeflabels(t "FY 12-13 Log Growth Rate")
		collabels(none)		
		cells(b(fmt(%12.3f))
		se(fmt(%12.3f) par)
		pval(fmt(%12.3f) par([ ]))
		)
		
		starlevels(* .10 ** .05 *** .01) // significance levels
		
		nolines
		noobs
		nonumbers
		nomtitles
		label // Use Variable Labels
		booktabs // a nicer version of tables
		fragment
		append
		;

# delimit cr

# delimit ;
	esttab stat_treaty1 stat_revy1 stat_demy1 stat_treaty2 stat_revy2 stat_demy2  stat_treaty3 stat_revy3 stat_demy3
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",
		drop(*)
		
		stats(
			jointp
			N,
			labels("RI P-val, joint significance" "N")
			fmt("%12.3f" "%12.0f")
		)
		
		extracols(1 4 7)
		
		noeqlines
		nonumbers
		nomtitles
		noobs
		label
		booktabs
		fragment
		append
		;

# delimit cr

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table presents balance tests for the randomization into the different treatments."
file write tablenote " Columns labelled Control reflect control group means."
file write tablenote " Values in the treatment columns are the coefficients of a regression of the baseline value of the variable indicated in the row on a treatment dummy (or the set of subtreatment dummies), controlling for the relevant randomization strata."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Randomization inference based p-values in brackets."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

* Cleans the balance table .tex file by removing the empty "(.)" below the Control means
shell python "`python_file'"
  
compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

}
