/*
Baseline preferences histograms

Author(s):
	Ismail Khan (2015-)

Date created:
	Jun 6, 2016

*/

********************************************************************************
* 0. Setup
********************************************************************************

clear all
set more off
pause off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Input files
local baseline_prefs = 			"Coded Data/Cleaned baseline preferences"

* Output files
local popularity_plot = 		"output/Paper/circle_popularity.eps"
local base_rank_dist = 			"output/Paper/baseline_rank_distribution.eps"

* Constants
local seed_val = 				12345
local num_iter = 				3


********************************************************************************
* 1. Randomly generate u1
********************************************************************************

use "`baseline_prefs'", clear

set seed `seed_val'
gen sort_order = .

* In each iteration, randomly generate preferences & calculate corresponding u1
forval i = 1/`num_iter' {
	
	* Generate random sort order
	replace sort_order = runiform()
	
	* Calculate u1 based on randomized order
	bys partition_name group hr_id (sort_order): gen rand_u1_`i' = 1 - ( (_n-1) / (num_ins_in_group-1) ) if !mi(ranking)
	replace rand_u1_`i' = 0 if rand_u1_`i' < 0 // These are circles where it is impossible for the inspector to be posted
}

drop sort_order

* Compute average u1 for each circle
egen rand_u1_mean = rowmean(rand_u1_1-rand_u1_`num_iter')
drop rand_u1_1-rand_u1_`num_iter'


********************************************************************************
* 2. Collapse dataset & plot histograms
********************************************************************************

collapse (mean) u1_mean=u1 rand_u1_mean=rand_u1_mean, by(circle_id)


twoway (histogram u1_mean, 		start(0) width(0.05) fraction) ///
       (histogram rand_u1_mean, start(0) width(0.05) fraction fcolor(none) lcolor(black)),  ///
	   legend(order(1 "u1 (actual)" 2 "u1 (random preferences)" ))
	   
graph export "`popularity_plot'", replace



********************************************************************************
* 3. Plot distribution of baseline rank of baseline circle
********************************************************************************

use "`baseline_prefs'", clear

* Keep only rows for circles in which inspectors are currently posted
keep if own_circle == 1
drop if mi(ranking)
drop norm_ranking ranking own_circle num_ins_in_group

* Reshape dataset so that each row corresponds with an inspector
bys partition_name group hr_id: gen j = _n
reshape wide circle_id u1, i(partition_name group hr_id) j(j)

* Generate variable for Ranked First at Baseline
gen best_u1 = max(u11, u12)

* Plot histogram
set scheme s1color
histogram best_u1, title("Distribution of Baseline Rank of Baseline Circle") xtitle("Rank (0-1 scale)") fraction
graph export "`base_rank_dist'", replace



