*! Version 1 31jan2014 Wayne Aaron Sandholtz
/* Give dolatest the name of a do file structured as ######`myfile'.do or
	path/path/######`myfile'.do -- just as you would give to do -- and it 
    will do the file with the most recent date of format YYMMDD`myfile'.do.
  NB1: the filename you feed dolatest doesn't have to actually exist; you could
    give it "Analysis/Do Files/999999_prep.do" and it would look through
	"Analysis/Do Files" for the version of ######_prep.do in which ######
	represents the most recent date.
  NB2: dolatest doesn't care about which file was actually created or
    modified most recently.  It just looks at the first six digits of the
    filenames themselves.
  NB3: dolatest will only run files whose ###### represent dates from $S_DATE or
    earlier.
*/
  
/* Ideas for improvements:
  - just cycle through the versions in the directory rather than decrementing
	day by day.
  - For now I'm not going to have it return any values because in some cases
	  the user might want to use returned values from whatever r-class command
	  happens at the end of the do-file called by dolatest. But these are the 
	  ones I would like to return (the locals are already grabbed in the file):
	* return local cmdline = `dolatest_cmdline'
	* return local dates = `dolatest_dates'
	* return local file = `dolatest_file'
	* return local date = `dolatest_date'
	* return local dir = `dolatest_dir'
*/
	
********************************************************************************
  
cap pr drop dolatest
program define dolatest, rclass
	version 13
	
	local dolatest_cmdline `0'
	
	** check that there is only one argument.
	if `"`2'"' != ""{ 
		di as error "Please include only one argument"
		di as error "(a filename of the kind you would feed to the do command)" 
		exit
	}
			
	** Find the number of \/-separated elements of the user input
	tokenize `0', parse(/\)
	local tokenlen = 0
	local i = 1
	while `tokenlen' == 0{
		if "``i''" == "" local tokenlen = `i' - 1
		local ++i
	}
	
	** Isolate the part of the user input that is just the filename (no path)
	local myfile = "``tokenlen''"
	
	** Take off any leading dates.
	local myfile = regexr("`myfile'","^[0-9][0-9][0-9][0-9][0-9][0-9]","")
	di in yellow "filename: " in green "`myfile'"
	
	** Put together the path
	local mydir
	forv i = 1/`= `tokenlen' - 1'{
		if "``i''" == "\" local `i' = "/"
		local mydir `mydir'``i''
	}
	di in yellow "directory: " in green `"`mydir'"'
	
	** Check that at least one file with the supplied name exists in the mydir
	** And also compile a list of the dates which appear in front of that file.
	local startdir `c(pwd)'
		/* we want to look in the directory they supply, but then send Stata
		  back to the directory it was in when the command was called. */
	quietly cd "`mydir'"
	local exists = 0
	local files: dir . files "*.do"
	foreach x in `files'{
		if regexm(lower("`x'"),lower("^([0-9][0-9][0-9][0-9][0-9][0-9])`myfile'$")){
			local exists = 1
		local dolatest_dates `dolatest_dates' `= regexs(1)'
		}
	}
	quietly cd "`startdir'"
	
	di in yellow "List of dates which appear before this filename in this directory:"
	di in green "`dolatest_dates'"
		
	if `exists' == 0{ 
		di as error "I find no filenames of the format ######`myfile'"
		di as error "in the specified directory `c(pwd)'/`mydir'"
		di as error "Maybe check spaces or underscores, or try a different directory"
		exit 601
	}
			
	** Find and run the file prefixed with the most recent date
	local sdate = date("$S_DATE","DMY") // start with today
	local lowerlimit = date("1Jan2010","DMY") // don't bother checking earlier
	local done 0
	while `done' == 0 & `sdate' > `lowerlimit'{ 
		** convert statadate to "YYMMDD" format
		local YY = substr("`= year(`sdate')'",3,2)
		local MM = "`= month(`sdate')'"
		if length("`MM'") == 1 local MM = "0" + "`MM'"
		local DD = "`= day(`sdate')'"
		if length("`DD'") == 1 local DD = "0" + "`DD'" 
		local cdate = "`YY'" + "`MM'" + "`DD'"
		
		** Try it, and run the do file if possible
		cap confirm file "`mydir'`cdate'`myfile'"
		if _rc == 0{
			local dolatest_file `cdate'`myfile'
			local dolatest_date `cdate'
			local dolatest_dir `mydir'
			di in yellow "Latest version: " in green "`cdate'`myfile'"
			
			do "`mydir'`cdate'`myfile'"
			local done = 1
		}
		** Or else look one day earlier
		else local --sdate
	}
end
